==> openGion6.1.2.0_dev.zip: uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF02S.sql <==
/****************************************************************************/
/* GF02 ( ﾃｰﾌﾞﾙ定義 )                                                       */
/*                                                                          */
/* Created : 2014/12/27 18:21:06                                            */
/****************************************************************************/
CREATE TABLE GF02 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL                        /*  10 ｼｽﾃﾑID           */
 , TBLSYU           VARCHAR (   1 )                 NOT NULL                        /*  20 ﾃｰﾌﾞﾙ種別        */
 , TABLE_NAME       VARCHAR (  50 )                 NOT NULL                        /*  30 ﾃｰﾌﾞﾙ名          */
 , NAME_JA          VARCHAR ( 200 )                                                 /*  40 名称             */
 , KBTBL            VARCHAR (   1 )                 NOT NULL                        /*  50 ﾃｰﾌﾞﾙ区分        */
 , SEQNO            INTEGER             DEFAULT 0   NOT NULL                        /*  60 表示順           */
 , TABLESPACE_NAME  VARCHAR (  30 )                                                 /*  70 ﾃｰﾌﾞﾙｽﾍﾟｰｽ名     */
 , INITIAL_EXTENT   BIGINT              DEFAULT 16                                  /*  90 初期ｴｸｽﾃﾝﾄ(KB)   */
 , COMMENTS         TEXT                                                            /* 110 ｺﾒﾝﾄ             */
 , SKENSU           INTEGER             DEFAULT 0   NOT NULL                        /* 170 想定件数         */
 , JKENSU           INTEGER             DEFAULT 0   NOT NULL                        /* 180 実件数           */
 , UNIQ             BIGINT                          NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL                        /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            VARCHAR (  14 )                                                 /* 820 登録日時         */
 , PGSET            VARCHAR (  10 )                                                 /* 830 作成PG           */
 , PGPSET           VARCHAR (  10 )                                                 /* 840 作成親PG         */
 , USRSET           VARCHAR (  10 )                                                 /* 850 作成社員         */
 , DYUPD            VARCHAR (  14 )                                                 /* 860 更新日時         */
 , PGUPD            VARCHAR (  10 )                                                 /* 870 更新PG           */
 , PGPUPD           VARCHAR (  10 )                                                 /* 880 更新親PG         */
 , USRUPD           VARCHAR (  10 )                                                 /* 890 更新者           */
);

==> openGion6.3.8.5_dev.zip: uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF02S.sql <==
/****************************************************************************/
/* GF02 ( ﾃｰﾌﾞﾙ定義 )                                                       */
/*                                                                          */
/* Created : 2015/09/17 15:31:15                                            */
/****************************************************************************/
CREATE TABLE GF02 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL                        /*  10 ｼｽﾃﾑID           */
 , TBLSYU           VARCHAR (   1 )                 NOT NULL                        /*  20 ﾃｰﾌﾞﾙ種別        */
 , TABLE_NAME       VARCHAR (  50 )                 NOT NULL                        /*  30 ﾃｰﾌﾞﾙ名          */
 , NAME_JA          VARCHAR ( 200 )                                                 /*  40 名称             */
 , KBTBL            VARCHAR (   1 )     DEFAULT '0' NOT NULL                        /*  50 ﾃｰﾌﾞﾙ区分        */
 , SEQNO            INTEGER             DEFAULT 0   NOT NULL                        /*  60 表示順           */
 , TABLESPACE_NAME  VARCHAR (  30 )                                                 /*  70 ﾃｰﾌﾞﾙｽﾍﾟｰｽ名     */
 , INITIAL_EXTENT   BIGINT              DEFAULT 16                                  /*  90 初期ｴｸｽﾃﾝﾄ(KB)   */
 , COMMENTS         TEXT                                                            /* 110 ｺﾒﾝﾄ             */
 , SKENSU           INTEGER             DEFAULT 0   NOT NULL                        /* 170 想定件数         */
 , JKENSU           INTEGER             DEFAULT 0   NOT NULL                        /* 180 実件数           */
 , UNIQ             BIGINT                          NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL                        /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            VARCHAR (  14 )                                                 /* 820 登録日時         */
 , PGSET            VARCHAR (  10 )                                                 /* 830 作成PG           */
 , PGPSET           VARCHAR (  10 )                                                 /* 840 作成親PG         */
 , USRSET           VARCHAR (  10 )                                                 /* 850 作成社員         */
 , DYUPD            VARCHAR (  14 )                                                 /* 860 更新日時         */
 , PGUPD            VARCHAR (  10 )                                                 /* 870 更新PG           */
 , PGPUPD           VARCHAR (  10 )                                                 /* 880 更新親PG         */
 , USRUPD           VARCHAR (  10 )                                                 /* 890 更新者           */
);
